# SPDX-FileCopyrightText: Copyright © 2023 Idiap Research Institute <contact@idiap.ch>
#
# SPDX-License-Identifier: GPL-3.0-or-later

"""CNN for radiological findings detection.

A Densenet121 model for radiological extraction
"""

from torch.nn import BCEWithLogitsLoss
from torch.optim import Adam

from ...models.densenet_rs import build_densenetrs

# Import the default protocol if none is available
if "dataset" not in locals():
    from ..datasets.nih_cxr14_re import default

    dataset = default.dataset

# config
lr = 1e-4

# model
model = build_densenetrs()

# optimizer
optimizer = Adam(
    filter(lambda p: p.requires_grad, model.model.model_ft.parameters()), lr=lr
)

# criterion
criterion = BCEWithLogitsLoss()
criterion_valid = BCEWithLogitsLoss()
