# SPDX-FileCopyrightText: Copyright © 2023 Idiap Research Institute <contact@idiap.ch>
#
# SPDX-License-Identifier: GPL-3.0-or-later

"""Test code for datasets."""

from ptbench.data.dataset import CSVDataset, JSONDataset
from ptbench.data.sample import Sample


def _raw_data_loader(context, d):
    return Sample(
        data=[
            float(d["sepal_length"]),
            float(d["sepal_width"]),
            float(d["petal_length"]),
            float(d["petal_width"]),
            d["species"][5:],
        ],
        key=(context["subset"] + str(context["order"])),
    )


def test_csv_loading(datadir):
    # tests if we can build a simple CSV loader for the Iris Flower dataset
    subsets = {
        "train": str(datadir / "iris-train.csv"),
        "test": str(datadir / "iris-train.csv"),
    }

    fieldnames = (
        "sepal_length",
        "sepal_width",
        "petal_length",
        "petal_width",
        "species",
    )

    dataset = CSVDataset(subsets, fieldnames, _raw_data_loader)
    dataset.check()

    data = dataset.subsets()

    assert len(data["train"]) == 75
    for k in data["train"]:
        for f in range(4):
            assert type(k.data[f]) == float
        assert type(k.data[4]) == str
        assert type(k.key) == str

    assert len(data["test"]) == 75
    for k in data["test"]:
        for f in range(4):
            assert type(k.data[f]) == float
        assert type(k.data[4]) == str
        assert k.data[4] in ("setosa", "versicolor", "virginica")
        assert type(k.key) == str


def test_json_loading(datadir):
    # tests if we can build a simple JSON loader for the Iris Flower dataset
    protocols = {"default": str(datadir / "iris.json")}

    fieldnames = (
        "sepal_length",
        "sepal_width",
        "petal_length",
        "petal_width",
        "species",
    )

    dataset = JSONDataset(protocols, fieldnames, _raw_data_loader)
    dataset.check()

    data = dataset.subsets("default")

    assert len(data["train"]) == 75
    for k in data["train"]:
        for f in range(4):
            assert type(k.data[f]) == float
        assert type(k.data[4]) == str
        assert type(k.key) == str

    assert len(data["test"]) == 75
    for k in data["test"]:
        for f in range(4):
            assert type(k.data[f]) == float
        assert type(k.data[4]) == str
        assert type(k.key) == str
